#!/bin/sh
set -e
if test -f "/run/secrets/db_password"; then
    pwd=`cat /run/secrets/db_password`
    if [ -z $pwd ]; then
        echo >&2 "error: /run/secrets/db_password is empty"
        exit 1
    fi
    export "DB_PASSWORD"="$pwd"
    unset "pwd"
else
    echo >&2 "error: /run/secrets/db_password does not exist"
    exit 1
fi

# we want to run some one-time tasks as described here:
# https://docs.pixelfed.org/running-pixelfed/installation.html#setting-up-services

if test ! -f /var/www/.env; then
    cp /envfile /var/www/.env
    chown www-data:www-data /var/www/.env
    chmod 755 /var/www/.env
    rm /envfile
else
    # this is a bit of a hack to move APP_KEY to the new env_file
    appkey=`grep 'APP_KEY=' /var/www/.env`
    sed "s/APP_KEY=/$appkey/g" /envfile > /newenv
    cp /newenv /var/www/.env
    chmod 755 /var/www/.env
    unset appkey
    rm /newenv
fi

/entrypoint.sh
